<?php
// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Get the active tab from the $_GET parameter
$default_tab = 'eztap-profile-settings';
$tab = isset($_GET['tab'])?sanitize_text_field($_GET['tab']):$default_tab;
$settings_url = "options-general.php?page=eztap-profile-button";
$eztap_profile_settings_url = admin_url($settings_url.'&tab=eztap-profile-settings');
$button_settings_url = admin_url($settings_url.'&tab=button-settings');

// Initialize variables
$ez_profile_link = get_option('EZ_profile_link');
$button_status = intval(get_option('EZ_button_status'));
$button_text = get_option('EZ_button_text');
$button_target = get_option('EZ_button_target');
$button_position = get_option('EZ_button_position');
$button_z_index = get_option('EZ_button_z_index');
$desktop_link_type = get_option('EZ_desktop_link_type');
$desktop_bottom_margin = intval(get_option('EZ_desktop_bottom_margin'));
$tablet_bottom_margin = intval(get_option('EZ_tablet_bottom_margin'));
$mobile_bottom_margin = intval(get_option('EZ_mobile_bottom_margin'));
?>

<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
    <nav class="nav-tab-wrapper">
        <a href="<?php echo esc_url($eztap_profile_settings_url); ?>" class="nav-tab <?php echo ($tab==='eztap-profile-settings')?'nav-tab-active':''; ?>"><?php echo esc_html__('EzTAP Profile Settings', 'ez'); ?></a>
        <a href="<?php echo esc_url($button_settings_url); ?>" class="nav-tab <?php echo ($tab==='button-settings')?'nav-tab-active':''; ?>"><?php echo esc_html__('Button Settings', 'ez'); ?></a>
    </nav>
    <div class="tab-content">
        <form method="post" action="options.php">
            <?php ($tab==='eztap-profile-settings')?settings_fields('scb-eztap-profile-settings'):settings_fields('scb-button-settings'); ?>
            <table class="form-table">
                <?php if ($tab==='eztap-profile-settings' || $tab!=='button-settings') { ?>
                    <tr>
                        <th scope="row"><?php echo esc_html__('EzTAP Profile Link', 'ez'); ?> :</th>
                        <td>
                            <input type="text" name="EZ_profile_link" id="EZ_profile_link" placeholder="<?php echo esc_html__('example_profile', 'ez'); ?>" dir="ltr" value="<?php echo esc_attr($ez_profile_link); ?>"/>
                            <p class="description"><?php echo esc_html__('Enter your profile/product link excluding app.eztap.in/profile?.', 'ez'); ?></p>
                        </td>
                    </tr>
                   
                <?php } elseif ($tab==='button-settings') { ?>
                    <tr>
                        <th scope="row"><?php echo esc_html__('Button status', 'ez'); ?> :</th>
                        <td>
                            <input type="checkbox" name="EZ_button_status" id="EZ_button_status" value="1" <?php checked('1', esc_attr($button_status));?>>
                            <span><?php echo esc_html__('Enabled', 'ez'); ?></span>
                        <td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo esc_html__('Button text', 'ez'); ?> <small style="font-weight: 400"><?php echo esc_html__('(optional)','ez'); ?></small> :</th>
                        <td>
                            <input type="text" name="EZ_button_text" id="EZ_button_text" placeholder="<?php echo esc_html__('Need Help?', 'ez'); ?>" value="<?php echo esc_attr($button_text);?>"/>
                            <p class="description"><?php echo esc_html__('Leave this field empty to only show an icon.', 'ez'); ?></p>
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><?php echo esc_html__('Open link in', 'ez'); ?> :</th>
                        <td>
                            <select name="EZ_button_target" id="EZ_button_target" >
                                <option <?php selected(esc_attr($button_target), '_blank'); ?> value="_blank"><?php echo esc_html__('New Tab', 'ez'); ?></option>
                                <option <?php selected(esc_attr($button_target), '_self'); ?> value="_self"><?php echo esc_html__('Current Tab', 'ez'); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo esc_html__('Position', 'ez'); ?> :</th>
                        <td>
                            <select name="EZ_button_position" id="EZ_button_position" >
                                <option <?php selected(esc_attr($button_position), 'right'); ?> value="right"><?php echo esc_html__('Bottom Right', 'ez'); ?></option>
                                <option <?php selected(esc_attr($button_position), 'left'); ?> value="left"><?php echo esc_html__('Bottom Left', 'ez'); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo esc_html__('Z-index', 'ez'); ?> :</th>
                        <td>
                            <input type="number" name="EZ_button_z_index" id="EZ_button_z_index" min="0" max="999999999" step="1" value="<?php echo esc_attr($button_z_index) ?>" placeholder="100"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo esc_html__('Bottom margin', 'ez'); ?> :</th>
                        <td>
                           <input type="number" name="EZ_desktop_bottom_margin" id="EZ_desktop_bottom_margin" min="0" max="100" step="1" value="<?php echo esc_attr($desktop_bottom_margin) ?>"/><span> <?php echo esc_html__('px (in Desktop)', 'ez'); ?> </span>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"</th>
                        <td>
                            <input type="number" name="EZ_tablet_bottom_margin" id="EZ_tablet_bottom_margin" min="0" max="100" step="1" value="<?php echo esc_attr($tablet_bottom_margin) ?>"/><span> <?php echo esc_html__('px (in Tablet)', 'ez'); ?> </span>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"></th>
                        <td>
                            <input type="number" name="EZ_mobile_bottom_margin" id="EZ_mobile_bottom_margin" min="0" max="100" step="1" value="<?php echo esc_attr($mobile_bottom_margin) ?>"/><span> <?php echo esc_html__('px (in Mobile)', 'ez'); ?> </span>
                        </td>
                    </tr>
                <?php } ?>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
</div>